import { AccountsAPI, BlocksAPI, DelegatesAPI, LoaderAPI, MultiSignaturesAPI, PeersAPI, SignaturesAPI, TransactionsAPI, TransportApi, TransportHeaders } from './types/apis/';
import { BaseApiResponse, cback as cbackType } from './types/base';
export * from './types/beans';
export interface RiseAPI extends APIWrapper {
    /**
     * Default Node Address: ex: http://localhost:1234 (no leading slash)
     */
    nodeAddress: string;
    /**
     * Timeout for default DposAPI requests
     */
    timeout: number;
    /**
     * Specify if error should be rewritten as response.
     */
    errorAsResponse: boolean;
    /**
     * Creates a new API Wrapper with the given node address.
     * So that you can be connected to multiple nodes at once.
     * @param nodeAddress Ex: http://localhost:1234 (no leading slash)
     * @param opts connection options
     */
    newWrapper(nodeAddress: string, opts?: {
        timeout: number;
    }): APIWrapper;
}
export interface APIWrapper {
    /**
     * Accounts APIs
     */
    accounts: AccountsAPI;
    /**
     * Blocks Query APIs
     */
    blocks: BlocksAPI;
    /**
     * Node loading status APIs
     */
    loader: LoaderAPI;
    /**
     * Transactions APIs
     */
    transactions: TransactionsAPI;
    /**
     * Peers APIs
     */
    peers: PeersAPI;
    /**
     * Signature APIs
     */
    signatures: SignaturesAPI;
    /**
     * Delegates APIs
     */
    delegates: DelegatesAPI;
    /**
     * Multi Signature Accounts APIs
     */
    multiSignatures: MultiSignaturesAPI;
    /**
     * Easily create a transport API without providing headers.
     * @param {boolean} flushCache flush current transportAPI cache
     * @returns {Promise<TransportApi>}
     */
    buildTransport: (flushCache?: boolean) => Promise<TransportApi>;
    /**
     * Access transport APIs
     * @param {TransportHeaders} headers
     * @returns {TransportApi}
     */
    transport: (headers: TransportHeaders) => TransportApi;
    rawRequest: <R>(obj: {
        noApiPrefix?: boolean;
        headers?: any;
        params?: any;
        path: string;
        method?: string;
        data?: any;
    }, cback: cbackType<R>) => Promise<R & BaseApiResponse>;
}
export declare const rise: RiseAPI;
